Package: PROMISE
Type: Package
Title: PRojection Onto the Most Interesting Statistical Evidence
Description: A general tool to identify genomic features with a
        specific biologically interesting pattern of associations with
        multiple endpoint variables as described in Pounds et. al.
        (2009) Bioinformatics 25: 2013-2019
Version: 1.62.0
Date: 2014-6-24
Author: Stan Pounds <stanley.pounds@stjude.org>, Xueyuan Cao
        <xueyuan.cao@stjude.org>
Maintainer: Stan Pounds <stanley.pounds@stjude.org>, Xueyuan Cao
 <xueyuan.cao@stjude.org>
Depends: R (>= 3.1.0), Biobase, GSEABase
Imports: Biobase, GSEABase, stats
License: GPL (>= 2)
LazyLoad: yes
biocViews: Microarray, OneChannel, MultipleComparison, GeneExpression
git_url: https://git.bioconductor.org/packages/PROMISE
git_branch: RELEASE_3_22
git_last_commit: 7bf04c1
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 04:58:51 UTC; biocbuild
Built: R 4.5.1; ; 2025-10-30 12:32:05 UTC; unix
