export("PROMISE", "avg.abs.genestat", "jung.rstat", "spearman.rstat", "promise.genestat")

importMethodsFrom(Biobase, exprs, pData, phenoData)
importMethodsFrom(GSEABase, geneIds, setName)
importFrom(stats, sd)
