
\name{sampGeneSet}
\alias{sampGeneSet}
\title{An Example Gene Set Collection}
\description{  
    This hypothetical gene set \emph{sampGeneSet} belongs to a \emph{GeneSetCollection} class. 
    It contains 10 gene sets (\emph{GeneSet} class). 
}
\usage{
data(sampGeneSet)
}
\keyword{misc}


